@@ -15,10 +15,8 @@ int main(int argc, char *argv[])
 
     viewer.engine()->addImportPath(QString("/opt/qtm11/imports"));
 
-    //BunkerFactory bunkerFactory;
-    //viewer.rootContext()->setContextProperty("bunkerFactory", &bunkerFactory);
-
-
+    viewer.setResizeMode(QDeclarativeView::SizeRootObjectToView);
+    viewer.setGeometry(100, 100, 640, 320);
     viewer.setMainQmlFile(QLatin1String("qml/pgz-spaceinvaders/main.qml"));
     viewer.showExpanded();
 
