@@ -351,7 +351,7 @@ function fire()
             shootSound.play();
         }
         bullet.x = ship.x + ship.width/2 - bullet.width/2;
-        bullet.y = ship.y
+        bullet.y = ship.y + ship.height - bullet.height;
     }
 }
 
@@ -363,10 +363,24 @@ function mainEvent() {
         mysteryShipHandling();
         checkCollisions();
         checkComplete();
+        checkGameOver();
 
     }
 }
 
+function checkGameOver()
+{
+    //See if any aliens are past the 'invade' line
+    for (var i = 0; i < 50; ++i) {
+        if (aliens[i]) {
+            if (aliens[i].y + aliens[i].height >= invadeline.y) {
+                cmdDead();
+                break
+            }
+        }
+    }
+}
+
 function moveBombs() {
     for (var i = 0; i < 10; ++i) {
         if (bombs[i]) {
@@ -411,8 +425,47 @@ function checkCollisions()
     checkBombBunkerCollision();
     checkBulletBunkerCollision();
     checkBulletMysteryCollision();
+    checkAlienBunkerCollision();
 }
 
+function checkAlienBunkerCollision()
+{
+    //Loop over each bomb checking if it has hit the ship
+    for (var i=0; i<50; i++) {
+        if (aliens[i]) { //Check if bomb object exist first
+            var x = aliens[i].x;
+            var y = aliens[i].y;
+            var w = aliens[i].width;
+            var h = aliens[i].height;
+
+            if (x >= bunker1.x - w && x <= bunker1.x + bunker1.width && ((y + h) >= bunker1.y)){
+                if (bunker1.checkCollision(x, y, w, h, true)) {
+                    continue;
+                }
+            }
+
+            if (x >= bunker2.x - w && x <= bunker2.x + bunker2.width && ((y + h) >= bunker2.y)){
+                if (bunker2.checkCollision(x, y, w, h, true)) {
+                    continue;
+                }
+            }
+
+            if (x >= bunker3.x - w && x <= bunker3.x + bunker3.width && ((y + h) >= bunker2.y)){
+                if (bunker3.checkCollision(x, y, w, h, true)) {
+                    continue;
+                }
+            }
+
+            if (x >= bunker4.x - w && x <= bunker4.x + bunker4.width && ((y + h) >= bunker2.y)){
+                if (bunker4.checkCollision(x, y, w, h, true)) {
+                    continue;
+                }
+            }
+        }
+    }
+}
+
+
 function checkBulletMysteryCollision()
 {
     if (bullet && mysteryShip) {
@@ -420,6 +473,7 @@ function checkBulletMysteryCollision()
             if (bullet.y > mysteryShip.y && bullet.y < mysteryShip.y + mysteryShip.height) {
                 if (Settings.SFX == "TRUE"){
                     destroyAlienSound.play();
+                    mysteryShipSound.stop();
                 }
 
                 score += mysteryShip.pointsAwarded;
@@ -440,7 +494,7 @@ function checkBulletAlienCollision()
     for (var i=0; i<50; i++) {
         if (bullet && aliens[i]) { //Check if objects exist first
             if (bullet.x > aliens[i].x && bullet.x < aliens[i].x + aliens[i].width) {
-                if (bullet.y > aliens[i].y && bullet.y < aliens[i].y + aliens[i].height) {
+                if ((bullet.y > aliens[i].y  || bullet.y + bullet.height > aliens[i].y) && bullet.y < aliens[i].y + aliens[i].height) {
                     if (Settings.SFX == "TRUE"){
                         destroyAlienSound.play();
                     }
@@ -553,6 +607,13 @@ function moveAliens() {
             if (aliens[i]) {
                 if (aliens[i].x + aliens[i].width > board.width - 10) {
                     aliendirection = -1;
+
+                    //Drop by 5px
+                    for (var i=0; i<50; i++) {
+                        if (aliens[i]) {
+                           aliens[i].y += 5;
+                        }
+                    }
                 }
             }
         }
@@ -669,13 +730,17 @@ function mysteryShipHandling()
             mysteryShip.x = board.width + 10;
             mysteryShip.y = closebutton.height + 5;
 
-            mysteryShipSound.play();
+            if (Settings.SFX == "TRUE"){
+                mysteryShipSound.play();
+            }
         }
     } else {
         if (mysteryShip.x > (0 - Sizer.mysteryWidth())) {
             mysteryShip.x -= 10;
         } else {
-            mysteryShipSound.stop();
+            if (Settings.SFX == "TRUE"){
+                mysteryShipSound.stop();
+            }
             mysteryShip.destroy();
             mysteryShip = null;
         }
